"use strict";

// Production webpack config for server code

var webpack = require('webpack');
var _require = require('kyt-utils/paths')(),
  serverSrcPath = _require.serverSrcPath,
  serverBuildPath = _require.serverBuildPath,
  publicSrcPath = _require.publicSrcPath;
var externals = require('./externals');
var postcssLoader = require('../utils/getPostcssLoader');
var getPolyfill = require('./getPolyfill');
module.exports = function (options) {
  return {
    mode: 'production',
    target: 'node',
    devtool: 'cheap-module-source-map',
    node: {
      __dirname: false,
      __filename: false
    },
    externals: externals(options.externalModulesAllowlist),
    entry: {
      main: [getPolyfill(options.type), "".concat(serverSrcPath, "/index.js")].filter(Boolean)
    },
    output: {
      path: serverBuildPath,
      filename: '[name].js',
      chunkFilename: '[name]-[chunkhash].js',
      publicPath: options.publicPath,
      libraryTarget: 'commonjs2'
    },
    module: {
      rules: [{
        test: /\.module\.(sc|c)ss$/,
        use: [{
          loader: 'css-loader',
          options: {
            modules: {
              localIdentName: '[name]-[local]--[hash:base64:5]',
              exportOnlyLocals: true
            }
          }
        }, postcssLoader, 'sass-loader'],
        exclude: [publicSrcPath]
      }]
    },
    plugins: [new webpack.BannerPlugin({
      banner: 'require("source-map-support").install();',
      raw: true,
      entryOnly: true
    })]
  };
};